==> docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0/luna-sdk_alma_rel_v.5.32.0/doc/fsdk/html/search/variables_a.js <==
var searchData=
[
  ['m_5fbytes',['m_bytes',['../structfsdk_1_1_sizer.html#a1ad20aaecf643c77e32067ac7619e59a',1,'fsdk::Sizer']]],
  ['m_5fdata',['m_data',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a2b853c76f9e36682a6955399565855d3',1,'fsdk::ISettingsProvider::Value::m_data()'],['../structfsdk_1_1_image.html#a378b11d6fc5fe3baa1f2e1a6fc0c7e68',1,'fsdk::Image::m_data()']]],
  ['m_5fdesc',['m_desc',['../structfsdk_1_1_i_settings_provider_1_1_desc.html#acca51618f5f65a44723b8396207535be',1,'fsdk::ISettingsProvider::Desc::m_desc()'],['../structfsdk_1_1_i_settings_provider_1_1_entry.html#ab62a7d512a201be88694b03f89a4f44a',1,'fsdk::ISettingsProvider::Entry::m_desc()']]],
  ['m_5fdeviceid',['m_deviceId',['../structfsdk_1_1_image.html#a8435a72e723aa1b3c818867457276c9a',1,'fsdk::Image']]],
  ['m_5ffloat1',['m_float1',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html#a77dc14765597fe4cf65da827a2c36d01',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['m_5ffloat2',['m_float2',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html#ab756fa69de93422f525aede6fd4d5dcb',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['m_5ffloat3',['m_float3',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html#a5ec6030828e645853be71394e3d22e8e',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['m_5ffloat4',['m_float4',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html#aec1196921ed7470f8869d930160883cf',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['m_5fformat',['m_format',['../structfsdk_1_1_image.html#aefe4793bcc5d38d828d5ead04cb4f75e',1,'fsdk::Image']]],
  ['m_5fheight',['m_height',['../structfsdk_1_1_image.html#aa4dee2d753540eb26aac388ed8d94ce9',1,'fsdk::Image']]],
  ['m_5fint1',['m_int1',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html#a19bebc0b9e17e194c981355ce0bfa90a',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['m_5fint2',['m_int2',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html#a9b685dfe0da1654cdbc72215f2db04ed',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['m_5fint3',['m_int3',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html#afa87698cc37557d1cae0bdafb2663ec4',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['m_5fint4',['m_int4',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html#a3e4b62bfb96be90b38126d7af628fef5',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['m_5fparameter',['m_parameter',['../structfsdk_1_1_i_settings_provider_1_1_key.html#a4a9ac00ecf0318698499bc7ca5a3dd6d',1,'fsdk::ISettingsProvider::Key']]],
  ['m_5fptr',['m_ptr',['../structfsdk_1_1_ref_base.html#ab57bc3fc17e734e742c0b47ec60573ba',1,'fsdk::RefBase']]],
  ['m_5fref',['m_ref',['../structfsdk_1_1_image.html#a4309931e1a59c9b88469a5633df36769',1,'fsdk::Image']]],
  ['m_5fsection',['m_section',['../structfsdk_1_1_i_settings_provider_1_1_key.html#a47c4fb20308ffab842f8c6b8771482c2',1,'fsdk::ISettingsProvider::Key']]],
  ['m_5fstring',['m_string',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html#aea8dd6b42c5e9ffa5ffebfb8e31e5b23',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['m_5ftype',['m_type',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a2eacc17be55f5b7c45b0b14dae8dabed',1,'fsdk::ISettingsProvider::Value::m_type()'],['../structfsdk_1_1_format.html#a708cc1ef87c456417c678e7720a52159',1,'fsdk::Format::m_type()']]],
  ['m_5fvalue',['m_value',['../structfsdk_1_1_i_settings_provider_1_1_entry.html#ac2bba965cd886b1f53b60ddf24f35df3',1,'fsdk::ISettingsProvider::Entry::m_value()'],['../structfsdk_1_1_result_value_3_01_r_00_01_v_00_01typename_01std_1_1enable__if_3_01std_1_1is__copy2f668dc7084c0a905cc04d7f40fbec0b.html#afef4906788a7f335f4b5a2a372551f8d',1,'fsdk::ResultValue&lt; R, V, typename std::enable_if&lt; std::is_copy_constructible&lt; V &gt;::value &gt;::type &gt;::m_value()'],['../structfsdk_1_1_result_value_3_01_r_00_01_v_00_01typename_01std_1_1enable__if_3_01std_1_1is__copy9c4ba859f69d23768930bdaf370a25f8.html#aa0af562d57def46e9945664991cabb73',1,'fsdk::ResultValue&lt; R, V, typename std::enable_if&lt; std::is_copy_constructible&lt; V &gt;::value==false &gt;::type &gt;::m_value()']]],
  ['m_5fwidth',['m_width',['../structfsdk_1_1_image.html#a32c6a6ef3700e9babb0943ce4aac6155',1,'fsdk::Image']]],
  ['major',['major',['../structfsdk_1_1_version.html#aa51eaf974da4d0a2fdc3bd41bd43df36',1,'fsdk::Version']]],
  ['male',['male',['../structfsdk_1_1_human_attribute_result_1_1_gender_estimation.html#a38587470ef671a56674afc9ebea6e19e',1,'fsdk::HumanAttributeResult::GenderEstimation']]],
  ['masknotinplace',['maskNotInPlace',['../structfsdk_1_1_medical_mask_estimation_extended.html#aa6a5ed18f25e9998ad1dd2fc280a3121',1,'fsdk::MedicalMaskEstimationExtended']]],
  ['maskscore',['maskScore',['../structfsdk_1_1_medical_mask_estimation.html#ad47aa0e8d3c14f07771adf4c6eb72624',1,'fsdk::MedicalMaskEstimation::maskScore()'],['../structfsdk_1_1_medical_mask_estimation_extended.html#a6c75dab32127e86880e8dd9726a9cd7f',1,'fsdk::MedicalMaskEstimationExtended::maskScore()']]],
  ['masktype',['maskType',['../structfsdk_1_1_medical_mask_estimation.html#a54b478e726656c252899b14719266dff',1,'fsdk::MedicalMaskEstimation']]],
  ['max',['max',['../structfsdk_1_1_depth_range.html#adb41f9726032424f94108b081322c182',1,'fsdk::DepthRange']]],
  ['max_5fsize',['max_size',['../structfsdk_1_1_fingerprint.html#a467cd5e68e56b2be521eff152f6bb7ef',1,'fsdk::Fingerprint']]],
  ['min',['min',['../structfsdk_1_1_depth_range.html#a37e59626029828b62a06a21cb2a12439',1,'fsdk::DepthRange']]],
  ['minor',['minor',['../structfsdk_1_1_version.html#a6ac214dbaed6cb0c9af597a0ce45fa73',1,'fsdk::Version']]],
  ['mustachescore',['mustacheScore',['../structfsdk_1_1_facial_hair_estimation.html#abd91ef42f365a32cc5f9ed13b61abd24',1,'fsdk::FacialHairEstimation']]]
];

==> docs_sdk_archive_luna-sdk_alma_rel_v.5.34.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.34.0/luna-sdk_alma_rel_v.5.34.0/doc/fsdk/html/search/variables_a.js <==
var searchData=
[
  ['m_5fbytes',['m_bytes',['../structfsdk_1_1_sizer.html#a1ad20aaecf643c77e32067ac7619e59a',1,'fsdk::Sizer']]],
  ['m_5fdata',['m_data',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a2b853c76f9e36682a6955399565855d3',1,'fsdk::ISettingsProvider::Value::m_data()'],['../structfsdk_1_1_image.html#a378b11d6fc5fe3baa1f2e1a6fc0c7e68',1,'fsdk::Image::m_data()']]],
  ['m_5fdesc',['m_desc',['../structfsdk_1_1_i_settings_provider_1_1_desc.html#acca51618f5f65a44723b8396207535be',1,'fsdk::ISettingsProvider::Desc::m_desc()'],['../structfsdk_1_1_i_settings_provider_1_1_entry.html#ab62a7d512a201be88694b03f89a4f44a',1,'fsdk::ISettingsProvider::Entry::m_desc()']]],
  ['m_5fdeviceid',['m_deviceId',['../structfsdk_1_1_image.html#a8435a72e723aa1b3c818867457276c9a',1,'fsdk::Image']]],
  ['m_5ffloat1',['m_float1',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html#a77dc14765597fe4cf65da827a2c36d01',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['m_5ffloat2',['m_float2',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html#ab756fa69de93422f525aede6fd4d5dcb',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['m_5ffloat3',['m_float3',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html#a5ec6030828e645853be71394e3d22e8e',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['m_5ffloat4',['m_float4',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html#aec1196921ed7470f8869d930160883cf',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['m_5fformat',['m_format',['../structfsdk_1_1_image.html#aefe4793bcc5d38d828d5ead04cb4f75e',1,'fsdk::Image']]],
  ['m_5fheight',['m_height',['../structfsdk_1_1_image.html#aa4dee2d753540eb26aac388ed8d94ce9',1,'fsdk::Image']]],
  ['m_5fint1',['m_int1',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html#a19bebc0b9e17e194c981355ce0bfa90a',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['m_5fint2',['m_int2',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html#a9b685dfe0da1654cdbc72215f2db04ed',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['m_5fint3',['m_int3',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html#afa87698cc37557d1cae0bdafb2663ec4',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['m_5fint4',['m_int4',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html#a3e4b62bfb96be90b38126d7af628fef5',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['m_5fparameter',['m_parameter',['../structfsdk_1_1_i_settings_provider_1_1_key.html#a4a9ac00ecf0318698499bc7ca5a3dd6d',1,'fsdk::ISettingsProvider::Key']]],
  ['m_5fptr',['m_ptr',['../structfsdk_1_1_ref_base.html#ab57bc3fc17e734e742c0b47ec60573ba',1,'fsdk::RefBase']]],
  ['m_5fref',['m_ref',['../structfsdk_1_1_image.html#a4309931e1a59c9b88469a5633df36769',1,'fsdk::Image']]],
  ['m_5fsection',['m_section',['../structfsdk_1_1_i_settings_provider_1_1_key.html#a47c4fb20308ffab842f8c6b8771482c2',1,'fsdk::ISettingsProvider::Key']]],
  ['m_5fstring',['m_string',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html#aea8dd6b42c5e9ffa5ffebfb8e31e5b23',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['m_5ftype',['m_type',['../structfsdk_1_1_i_settings_provider_1_1_value.html#a2eacc17be55f5b7c45b0b14dae8dabed',1,'fsdk::ISettingsProvider::Value::m_type()'],['../structfsdk_1_1_format.html#a708cc1ef87c456417c678e7720a52159',1,'fsdk::Format::m_type()']]],
  ['m_5fulong',['m_uLong',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html#a0cfe692790aed45772cb30851ef3ad45',1,'fsdk::ISettingsProvider::Value::Data']]],
  ['m_5fvalue',['m_value',['../structfsdk_1_1_i_settings_provider_1_1_entry.html#ac2bba965cd886b1f53b60ddf24f35df3',1,'fsdk::ISettingsProvider::Entry::m_value()'],['../structfsdk_1_1_result_value_3_01_r_00_01_v_00_01typename_01std_1_1enable__if_3_01std_1_1is__copy2f668dc7084c0a905cc04d7f40fbec0b.html#afef4906788a7f335f4b5a2a372551f8d',1,'fsdk::ResultValue&lt; R, V, typename std::enable_if&lt; std::is_copy_constructible&lt; V &gt;::value &gt;::type &gt;::m_value()'],['../structfsdk_1_1_result_value_3_01_r_00_01_v_00_01typename_01std_1_1enable__if_3_01std_1_1is__copy9c4ba859f69d23768930bdaf370a25f8.html#aa0af562d57def46e9945664991cabb73',1,'fsdk::ResultValue&lt; R, V, typename std::enable_if&lt; std::is_copy_constructible&lt; V &gt;::value==false &gt;::type &gt;::m_value()']]],
  ['m_5fwidth',['m_width',['../structfsdk_1_1_image.html#a32c6a6ef3700e9babb0943ce4aac6155',1,'fsdk::Image']]],
  ['major',['major',['../structfsdk_1_1_version.html#aa51eaf974da4d0a2fdc3bd41bd43df36',1,'fsdk::Version']]],
  ['male',['male',['../structfsdk_1_1_human_attribute_result_1_1_gender_estimation.html#a38587470ef671a56674afc9ebea6e19e',1,'fsdk::HumanAttributeResult::GenderEstimation']]],
  ['masknotinplace',['maskNotInPlace',['../structfsdk_1_1_medical_mask_estimation_extended.html#aa6a5ed18f25e9998ad1dd2fc280a3121',1,'fsdk::MedicalMaskEstimationExtended']]],
  ['maskscore',['maskScore',['../structfsdk_1_1_medical_mask_estimation.html#ad47aa0e8d3c14f07771adf4c6eb72624',1,'fsdk::MedicalMaskEstimation::maskScore()'],['../structfsdk_1_1_medical_mask_estimation_extended.html#a6c75dab32127e86880e8dd9726a9cd7f',1,'fsdk::MedicalMaskEstimationExtended::maskScore()']]],
  ['masktype',['maskType',['../structfsdk_1_1_medical_mask_estimation.html#a54b478e726656c252899b14719266dff',1,'fsdk::MedicalMaskEstimation']]],
  ['max_5fsize',['max_size',['../structfsdk_1_1_fingerprint.html#a467cd5e68e56b2be521eff152f6bb7ef',1,'fsdk::Fingerprint::max_size()'],['../structfsdk_1_1_a_i_d.html#a65e6e2fd747f1eba6ab91a41f60b6490',1,'fsdk::AID::max_size()']]],
  ['minor',['minor',['../structfsdk_1_1_version.html#a6ac214dbaed6cb0c9af597a0ce45fa73',1,'fsdk::Version']]],
  ['mustachescore',['mustacheScore',['../structfsdk_1_1_facial_hair_estimation.html#abd91ef42f365a32cc5f9ed13b61abd24',1,'fsdk::FacialHairEstimation']]]
];
